# langchain-anthropic

This package contains the LangChain integration for Anthropic's generative models.

View the [documentation](https://docs.langchain.com/oss/python/integrations/providers/anthropic) for more details.
